==> verifiedpermissions-2.30.0-sources.jar: software/amazon/awssdk/services/verifiedpermissions/model/ValidationException.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.verifiedpermissions.model;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.BiConsumer;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.awscore.exception.AwsErrorDetails;
import software.amazon.awssdk.core.SdkField;
import software.amazon.awssdk.core.SdkPojo;
import software.amazon.awssdk.core.protocol.MarshallLocation;
import software.amazon.awssdk.core.protocol.MarshallingType;
import software.amazon.awssdk.core.traits.ListTrait;
import software.amazon.awssdk.core.traits.LocationTrait;
import software.amazon.awssdk.core.util.DefaultSdkAutoConstructList;
import software.amazon.awssdk.core.util.SdkAutoConstructList;
import software.amazon.awssdk.utils.builder.CopyableBuilder;
import software.amazon.awssdk.utils.builder.ToCopyableBuilder;

/**
 * <p>
 * The request failed because one or more input parameters don't satisfy their constraint requirements. The output is
 * provided as a list of fields and a reason for each field that isn't valid.
 * </p>
 * <p>
 * The possible reasons include the following:
 * </p>
 * <ul>
 * <li>
 * <p>
 * <b>UnrecognizedEntityType</b>
 * </p>
 * <p>
 * The policy includes an entity type that isn't found in the schema.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnrecognizedActionId</b>
 * </p>
 * <p>
 * The policy includes an action id that isn't found in the schema.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>InvalidActionApplication</b>
 * </p>
 * <p>
 * The policy includes an action that, according to the schema, doesn't support the specified principal and resource.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnexpectedType</b>
 * </p>
 * <p>
 * The policy included an operand that isn't a valid type for the specified operation.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>IncompatibleTypes</b>
 * </p>
 * <p>
 * The types of elements included in a <code>set</code>, or the types of expressions used in an
 * <code>if...then...else</code> clause aren't compatible in this context.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>MissingAttribute</b>
 * </p>
 * <p>
 * The policy attempts to access a record or entity attribute that isn't specified in the schema. Test for the existence
 * of the attribute first before attempting to access its value. For more information, see the <a
 * href="https://docs.cedarpolicy.com/policies/syntax-operators.html#has-presence-of-attribute-test">has (presence of
 * attribute test) operator</a> in the <i>Cedar Policy Language Guide</i>.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnsafeOptionalAttributeAccess</b>
 * </p>
 * <p>
 * The policy attempts to access a record or entity attribute that is optional and isn't guaranteed to be present. Test
 * for the existence of the attribute first before attempting to access its value. For more information, see the <a
 * href="https://docs.cedarpolicy.com/policies/syntax-operators.html#has-presence-of-attribute-test">has (presence of
 * attribute test) operator</a> in the <i>Cedar Policy Language Guide</i>.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>ImpossiblePolicy</b>
 * </p>
 * <p>
 * Cedar has determined that a policy condition always evaluates to false. If the policy is always false, it can never
 * apply to any query, and so it can never affect an authorization decision.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>WrongNumberArguments</b>
 * </p>
 * <p>
 * The policy references an extension type with the wrong number of arguments.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>FunctionArgumentValidationError</b>
 * </p>
 * <p>
 * Cedar couldn't parse the argument passed to an extension type. For example, a string that is to be parsed as an IPv4
 * address can contain only digits and the period character.
 * </p>
 * </li>
 * </ul>
 */
@Generated("software.amazon.awssdk:codegen")
public final class ValidationException extends VerifiedPermissionsException implements
        ToCopyableBuilder<ValidationException.Builder, ValidationException> {
    private static final SdkField<List<ValidationExceptionField>> FIELD_LIST_FIELD = SdkField
            .<List<ValidationExceptionField>> builder(MarshallingType.LIST)
            .memberName("fieldList")
            .getter(getter(ValidationException::fieldList))
            .setter(setter(Builder::fieldList))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("fieldList").build(),
                    ListTrait
                            .builder()
                            .memberLocationName(null)
                            .memberFieldInfo(
                                    SdkField.<ValidationExceptionField> builder(MarshallingType.SDK_POJO)
                                            .constructor(ValidationExceptionField::builder)
                                            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD)
                                                    .locationName("member").build()).build()).build()).build();

    private static final List<SdkField<?>> SDK_FIELDS = Collections.unmodifiableList(Arrays.asList(FIELD_LIST_FIELD));

    private static final Map<String, SdkField<?>> SDK_NAME_TO_FIELD = memberNameToFieldInitializer();

    private static final long serialVersionUID = 1L;

    private final List<ValidationExceptionField> fieldList;

    private ValidationException(BuilderImpl builder) {
        super(builder);
        this.fieldList = builder.fieldList;
    }

    @Override
    public Builder toBuilder() {
        return new BuilderImpl(this);
    }

    public static Builder builder() {
        return new BuilderImpl();
    }

    public static Class<? extends Builder> serializableBuilderClass() {
        return BuilderImpl.class;
    }

    /**
     * For responses, this returns true if the service returned a value for the FieldList property. This DOES NOT check
     * that the value is non-empty (for which, you should check the {@code isEmpty()} method on the property). This is
     * useful because the SDK will never return a null collection or map, but you may need to differentiate between the
     * service returning nothing (or null) and the service returning an empty collection or map. For requests, this
     * returns true if a value for the property was specified in the request builder, and false if a value was not
     * specified.
     */
    public boolean hasFieldList() {
        return fieldList != null && !(fieldList instanceof SdkAutoConstructList);
    }

    /**
     * <p>
     * The list of fields that aren't valid.
     * </p>
     * <p>
     * Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
     * </p>
     * <p>
     * This method will never return null. If you would like to know whether the service returned this field (so that
     * you can differentiate between null and empty), you can use the {@link #hasFieldList} method.
     * </p>
     * 
     * @return The list of fields that aren't valid.
     */
    public List<ValidationExceptionField> fieldList() {
        return fieldList;
    }

    @Override
    public final List<SdkField<?>> sdkFields() {
        return SDK_FIELDS;
    }

    @Override
    public final Map<String, SdkField<?>> sdkFieldNameToField() {
        return SDK_NAME_TO_FIELD;
    }

    private static Map<String, SdkField<?>> memberNameToFieldInitializer() {
        Map<String, SdkField<?>> map = new HashMap<>();
        map.put("fieldList", FIELD_LIST_FIELD);
        return Collections.unmodifiableMap(map);
    }

    private static <T> Function<Object, T> getter(Function<ValidationException, T> g) {
        return obj -> g.apply((ValidationException) obj);
    }

    private static <T> BiConsumer<Object, T> setter(BiConsumer<Builder, T> s) {
        return (obj, val) -> s.accept((Builder) obj, val);
    }

    public interface Builder extends SdkPojo, CopyableBuilder<Builder, ValidationException>, VerifiedPermissionsException.Builder {
        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * 
         * @param fieldList
         *        The list of fields that aren't valid.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder fieldList(Collection<ValidationExceptionField> fieldList);

        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * 
         * @param fieldList
         *        The list of fields that aren't valid.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder fieldList(ValidationExceptionField... fieldList);

        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * This is a convenience method that creates an instance of the
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder} avoiding
         * the need to create one manually via
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField#builder()}.
         *
         * <p>
         * When the {@link Consumer} completes,
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder#build()} is
         * called immediately and its result is passed to {@link #fieldList(List<ValidationExceptionField>)}.
         * 
         * @param fieldList
         *        a consumer that will call methods on
         *        {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder}
         * @return Returns a reference to this object so that method calls can be chained together.
         * @see #fieldList(java.util.Collection<ValidationExceptionField>)
         */
        Builder fieldList(Consumer<ValidationExceptionField.Builder>... fieldList);

        @Override
        Builder awsErrorDetails(AwsErrorDetails awsErrorDetails);

        @Override
        Builder message(String message);

        @Override
        Builder requestId(String requestId);

        @Override
        Builder statusCode(int statusCode);

        @Override
        Builder cause(Throwable cause);

        @Override
        Builder writableStackTrace(Boolean writableStackTrace);
    }

    static final class BuilderImpl extends VerifiedPermissionsException.BuilderImpl implements Builder {
        private List<ValidationExceptionField> fieldList = DefaultSdkAutoConstructList.getInstance();

        private BuilderImpl() {
        }

        private BuilderImpl(ValidationException model) {
            super(model);
            fieldList(model.fieldList);
        }

        public final List<ValidationExceptionField.Builder> getFieldList() {
            List<ValidationExceptionField.Builder> result = ValidationExceptionFieldListCopier.copyToBuilder(this.fieldList);
            if (result instanceof SdkAutoConstructList) {
                return null;
            }
            return result;
        }

        public final void setFieldList(Collection<ValidationExceptionField.BuilderImpl> fieldList) {
            this.fieldList = ValidationExceptionFieldListCopier.copyFromBuilder(fieldList);
        }

        @Override
        public final Builder fieldList(Collection<ValidationExceptionField> fieldList) {
            this.fieldList = ValidationExceptionFieldListCopier.copy(fieldList);
            return this;
        }

        @Override
        @SafeVarargs
        public final Builder fieldList(ValidationExceptionField... fieldList) {
            fieldList(Arrays.asList(fieldList));
            return this;
        }

        @Override
        @SafeVarargs
        public final Builder fieldList(Consumer<ValidationExceptionField.Builder>... fieldList) {
            fieldList(Stream.of(fieldList).map(c -> ValidationExceptionField.builder().applyMutation(c).build())
                    .collect(Collectors.toList()));
            return this;
        }

        @Override
        public BuilderImpl awsErrorDetails(AwsErrorDetails awsErrorDetails) {
            this.awsErrorDetails = awsErrorDetails;
            return this;
        }

        @Override
        public BuilderImpl message(String message) {
            this.message = message;
            return this;
        }

        @Override
        public BuilderImpl requestId(String requestId) {
            this.requestId = requestId;
            return this;
        }

        @Override
        public BuilderImpl statusCode(int statusCode) {
            this.statusCode = statusCode;
            return this;
        }

        @Override
        public BuilderImpl cause(Throwable cause) {
            this.cause = cause;
            return this;
        }

        @Override
        public BuilderImpl writableStackTrace(Boolean writableStackTrace) {
            this.writableStackTrace = writableStackTrace;
            return this;
        }

        @Override
        public ValidationException build() {
            return new ValidationException(this);
        }

        @Override
        public List<SdkField<?>> sdkFields() {
            return SDK_FIELDS;
        }

        @Override
        public Map<String, SdkField<?>> sdkFieldNameToField() {
            return SDK_NAME_TO_FIELD;
        }
    }
}

==> verifiedpermissions-2.40.1-sources.jar: software/amazon/awssdk/services/verifiedpermissions/model/ValidationException.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.verifiedpermissions.model;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.BiConsumer;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.annotations.Mutable;
import software.amazon.awssdk.annotations.NotThreadSafe;
import software.amazon.awssdk.awscore.exception.AwsErrorDetails;
import software.amazon.awssdk.core.SdkField;
import software.amazon.awssdk.core.SdkPojo;
import software.amazon.awssdk.core.protocol.MarshallLocation;
import software.amazon.awssdk.core.protocol.MarshallingType;
import software.amazon.awssdk.core.traits.ListTrait;
import software.amazon.awssdk.core.traits.LocationTrait;
import software.amazon.awssdk.core.util.DefaultSdkAutoConstructList;
import software.amazon.awssdk.core.util.SdkAutoConstructList;
import software.amazon.awssdk.utils.builder.CopyableBuilder;
import software.amazon.awssdk.utils.builder.ToCopyableBuilder;

/**
 * <p>
 * The request failed because one or more input parameters don't satisfy their constraint requirements. The output is
 * provided as a list of fields and a reason for each field that isn't valid.
 * </p>
 * <p>
 * The possible reasons include the following:
 * </p>
 * <ul>
 * <li>
 * <p>
 * <b>UnrecognizedEntityType</b>
 * </p>
 * <p>
 * The policy includes an entity type that isn't found in the schema.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnrecognizedActionId</b>
 * </p>
 * <p>
 * The policy includes an action id that isn't found in the schema.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>InvalidActionApplication</b>
 * </p>
 * <p>
 * The policy includes an action that, according to the schema, doesn't support the specified principal and resource.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnexpectedType</b>
 * </p>
 * <p>
 * The policy included an operand that isn't a valid type for the specified operation.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>IncompatibleTypes</b>
 * </p>
 * <p>
 * The types of elements included in a <code>set</code>, or the types of expressions used in an
 * <code>if...then...else</code> clause aren't compatible in this context.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>MissingAttribute</b>
 * </p>
 * <p>
 * The policy attempts to access a record or entity attribute that isn't specified in the schema. Test for the existence
 * of the attribute first before attempting to access its value. For more information, see the <a
 * href="https://docs.cedarpolicy.com/policies/syntax-operators.html#has-presence-of-attribute-test">has (presence of
 * attribute test) operator</a> in the <i>Cedar Policy Language Guide</i>.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>UnsafeOptionalAttributeAccess</b>
 * </p>
 * <p>
 * The policy attempts to access a record or entity attribute that is optional and isn't guaranteed to be present. Test
 * for the existence of the attribute first before attempting to access its value. For more information, see the <a
 * href="https://docs.cedarpolicy.com/policies/syntax-operators.html#has-presence-of-attribute-test">has (presence of
 * attribute test) operator</a> in the <i>Cedar Policy Language Guide</i>.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>ImpossiblePolicy</b>
 * </p>
 * <p>
 * Cedar has determined that a policy condition always evaluates to false. If the policy is always false, it can never
 * apply to any query, and so it can never affect an authorization decision.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>WrongNumberArguments</b>
 * </p>
 * <p>
 * The policy references an extension type with the wrong number of arguments.
 * </p>
 * </li>
 * <li>
 * <p>
 * <b>FunctionArgumentValidationError</b>
 * </p>
 * <p>
 * Cedar couldn't parse the argument passed to an extension type. For example, a string that is to be parsed as an IPv4
 * address can contain only digits and the period character.
 * </p>
 * </li>
 * </ul>
 */
@Generated("software.amazon.awssdk:codegen")
public final class ValidationException extends VerifiedPermissionsException implements
        ToCopyableBuilder<ValidationException.Builder, ValidationException> {
    private static final SdkField<List<ValidationExceptionField>> FIELD_LIST_FIELD = SdkField
            .<List<ValidationExceptionField>> builder(MarshallingType.LIST)
            .memberName("fieldList")
            .getter(getter(ValidationException::fieldList))
            .setter(setter(Builder::fieldList))
            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD).locationName("fieldList").build(),
                    ListTrait
                            .builder()
                            .memberLocationName(null)
                            .memberFieldInfo(
                                    SdkField.<ValidationExceptionField> builder(MarshallingType.SDK_POJO)
                                            .constructor(ValidationExceptionField::builder)
                                            .traits(LocationTrait.builder().location(MarshallLocation.PAYLOAD)
                                                    .locationName("member").build()).build()).build()).build();

    private static final List<SdkField<?>> SDK_FIELDS = Collections.unmodifiableList(Arrays.asList(FIELD_LIST_FIELD));

    private static final Map<String, SdkField<?>> SDK_NAME_TO_FIELD = memberNameToFieldInitializer();

    private static final long serialVersionUID = 1L;

    private final List<ValidationExceptionField> fieldList;

    private ValidationException(BuilderImpl builder) {
        super(builder);
        this.fieldList = builder.fieldList;
    }

    @Override
    public Builder toBuilder() {
        return new BuilderImpl(this);
    }

    public static Builder builder() {
        return new BuilderImpl();
    }

    public static Class<? extends Builder> serializableBuilderClass() {
        return BuilderImpl.class;
    }

    /**
     * For responses, this returns true if the service returned a value for the FieldList property. This DOES NOT check
     * that the value is non-empty (for which, you should check the {@code isEmpty()} method on the property). This is
     * useful because the SDK will never return a null collection or map, but you may need to differentiate between the
     * service returning nothing (or null) and the service returning an empty collection or map. For requests, this
     * returns true if a value for the property was specified in the request builder, and false if a value was not
     * specified.
     */
    public boolean hasFieldList() {
        return fieldList != null && !(fieldList instanceof SdkAutoConstructList);
    }

    /**
     * <p>
     * The list of fields that aren't valid.
     * </p>
     * <p>
     * Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
     * </p>
     * <p>
     * This method will never return null. If you would like to know whether the service returned this field (so that
     * you can differentiate between null and empty), you can use the {@link #hasFieldList} method.
     * </p>
     * 
     * @return The list of fields that aren't valid.
     */
    public List<ValidationExceptionField> fieldList() {
        return fieldList;
    }

    @Override
    public final List<SdkField<?>> sdkFields() {
        return SDK_FIELDS;
    }

    @Override
    public final Map<String, SdkField<?>> sdkFieldNameToField() {
        return SDK_NAME_TO_FIELD;
    }

    private static Map<String, SdkField<?>> memberNameToFieldInitializer() {
        Map<String, SdkField<?>> map = new HashMap<>();
        map.put("fieldList", FIELD_LIST_FIELD);
        return Collections.unmodifiableMap(map);
    }

    private static <T> Function<Object, T> getter(Function<ValidationException, T> g) {
        return obj -> g.apply((ValidationException) obj);
    }

    private static <T> BiConsumer<Object, T> setter(BiConsumer<Builder, T> s) {
        return (obj, val) -> s.accept((Builder) obj, val);
    }

    @Mutable
    @NotThreadSafe
    public interface Builder extends SdkPojo, CopyableBuilder<Builder, ValidationException>, VerifiedPermissionsException.Builder {
        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * 
         * @param fieldList
         *        The list of fields that aren't valid.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder fieldList(Collection<ValidationExceptionField> fieldList);

        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * 
         * @param fieldList
         *        The list of fields that aren't valid.
         * @return Returns a reference to this object so that method calls can be chained together.
         */
        Builder fieldList(ValidationExceptionField... fieldList);

        /**
         * <p>
         * The list of fields that aren't valid.
         * </p>
         * This is a convenience method that creates an instance of the
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder} avoiding
         * the need to create one manually via
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField#builder()}.
         *
         * <p>
         * When the {@link Consumer} completes,
         * {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder#build()} is
         * called immediately and its result is passed to {@link #fieldList(List<ValidationExceptionField>)}.
         * 
         * @param fieldList
         *        a consumer that will call methods on
         *        {@link software.amazon.awssdk.services.verifiedpermissions.model.ValidationExceptionField.Builder}
         * @return Returns a reference to this object so that method calls can be chained together.
         * @see #fieldList(java.util.Collection<ValidationExceptionField>)
         */
        Builder fieldList(Consumer<ValidationExceptionField.Builder>... fieldList);

        @Override
        Builder awsErrorDetails(AwsErrorDetails awsErrorDetails);

        @Override
        Builder message(String message);

        @Override
        Builder requestId(String requestId);

        @Override
        Builder statusCode(int statusCode);

        @Override
        Builder cause(Throwable cause);

        @Override
        Builder writableStackTrace(Boolean writableStackTrace);

        @Override
        Builder numAttempts(Integer numAttempts);
    }

    static final class BuilderImpl extends VerifiedPermissionsException.BuilderImpl implements Builder {
        private List<ValidationExceptionField> fieldList = DefaultSdkAutoConstructList.getInstance();

        private BuilderImpl() {
        }

        private BuilderImpl(ValidationException model) {
            super(model);
            fieldList(model.fieldList);
        }

        public final List<ValidationExceptionField.Builder> getFieldList() {
            List<ValidationExceptionField.Builder> result = ValidationExceptionFieldListCopier.copyToBuilder(this.fieldList);
            if (result instanceof SdkAutoConstructList) {
                return null;
            }
            return result;
        }

        public final void setFieldList(Collection<ValidationExceptionField.BuilderImpl> fieldList) {
            this.fieldList = ValidationExceptionFieldListCopier.copyFromBuilder(fieldList);
        }

        @Override
        public final Builder fieldList(Collection<ValidationExceptionField> fieldList) {
            this.fieldList = ValidationExceptionFieldListCopier.copy(fieldList);
            return this;
        }

        @Override
        @SafeVarargs
        public final Builder fieldList(ValidationExceptionField... fieldList) {
            fieldList(Arrays.asList(fieldList));
            return this;
        }

        @Override
        @SafeVarargs
        public final Builder fieldList(Consumer<ValidationExceptionField.Builder>... fieldList) {
            fieldList(Stream.of(fieldList).map(c -> ValidationExceptionField.builder().applyMutation(c).build())
                    .collect(Collectors.toList()));
            return this;
        }

        @Override
        public BuilderImpl awsErrorDetails(AwsErrorDetails awsErrorDetails) {
            this.awsErrorDetails = awsErrorDetails;
            return this;
        }

        @Override
        public BuilderImpl message(String message) {
            this.message = message;
            return this;
        }

        @Override
        public BuilderImpl requestId(String requestId) {
            this.requestId = requestId;
            return this;
        }

        @Override
        public BuilderImpl statusCode(int statusCode) {
            this.statusCode = statusCode;
            return this;
        }

        @Override
        public BuilderImpl cause(Throwable cause) {
            this.cause = cause;
            return this;
        }

        @Override
        public BuilderImpl writableStackTrace(Boolean writableStackTrace) {
            this.writableStackTrace = writableStackTrace;
            return this;
        }

        @Override
        public BuilderImpl numAttempts(Integer numAttempts) {
            this.numAttempts = numAttempts;
            return this;
        }

        @Override
        public ValidationException build() {
            return new ValidationException(this);
        }

        @Override
        public List<SdkField<?>> sdkFields() {
            return SDK_FIELDS;
        }

        @Override
        public Map<String, SdkField<?>> sdkFieldNameToField() {
            return SDK_NAME_TO_FIELD;
        }
    }
}
